@@ -31,7 +31,7 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import, annotations
+from __future__ import annotations
 
 import subprocess
 from typing import Dict, List
