@@ -38,10 +38,11 @@ import json
 import os.path
 import shutil
 import tempfile
-from imghdr import what
 from pathlib import Path
 from urllib.parse import quote
 
+from filetype import guess
+
 from univention.portal import Plugin, config
 from univention.portal.log import get_logger
 
@@ -84,7 +85,7 @@ class MtimeBasedLazyFileReloader(Reloader):
     def _get_mtime(self):
         try:
             return os.stat(self._cache_file).st_mtime
-        except (EnvironmentError, AttributeError) as exc:
+        except (OSError, AttributeError) as exc:
             get_logger("cache").warning(f"Unable to get mtime for {exc}")
             return 0
 
@@ -113,7 +114,7 @@ class MtimeBasedLazyFileReloader(Reloader):
                 if fd:
                     try:
                         os.makedirs(os.path.dirname(self._cache_file))
-                    except EnvironmentError:
+                    except OSError:
                         pass
                     shutil.move(fd.name, self._cache_file)
                     self._mtime = self._get_mtime()
@@ -315,7 +316,8 @@ class PortalReloaderUDM(MtimeBasedLazyFileReloader):
             name = name.replace(
                 "/", "-",
             )  # name must not contain / and must be a path which can be accessed via the web!
-            extension = what(None, image) or "svg"
+            extension = getattr(guess(image), "extension", "svg")
+
             path = assets_root / "icons" / dirname / f"{name}.{extension}"
             path.write_bytes(image)
         except (OSError, TypeError):
